import AlarmLevelBox from '@/components/DictionaryBox/alarmLevel';
import TableActionCard from '@/components/TableActionCard';
import IsDelete from '@/components/TableActionCard/isDelete';
import { alarmLevelStatusEnum } from '@/enums/status';
import {
  deleteDeviceCategoryDeleteDeviceCategory,
  postDeviceCategoryGetDeviceCategoryList,
} from '@/services/device/DeviceCategory';
import { getInterfaces } from '@/services/alarm/Interfaces'
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { PageContainer, ProTable } from '@ant-design/pro-components';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Button, Space, Tag, message } from 'antd';
import React, { useRef, useState } from 'react';
import { proTablePaginationOptions } from '../../../../config/defaultTable';
import { proIconForTableActionStyle } from '../../../../config/defaultIcon';
import { EditOutlined } from '@ant-design/icons';
import CreateForm from './components/CreateForm';
import UpdateForm from './components/UpdateForm';
const InterfaceManageList: React.FC = () => {
  /**
   * @en-US International configuration
   * @zh-CN 国际化配置
   * */
  const intl = useIntl();
  const actionRef = useRef<ActionType>();
  //  动态设置每页数量
  const [currentPageSize, setCurrentPageSize] = useState<number>(10);

  const handleDestroy = async (selectedRow: API.DeviceCategory) => {
    deleteDeviceCategoryDeleteDeviceCategory({ id: selectedRow.id })
      .then(() => {
        message.success(intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }));
        actionRef.current?.reload();
      })
      .catch(() => {
        message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
      });
  };

  const [currentRow, setCurrentRow] = useState<API.DeviceCategory>();
  /**
   * @en-US Pop-up window of new window
   * @zh-CN 新建窗口的弹窗
   *  */
  const [createModalOpen, setCreateModalOpen] = useState<boolean>(false);
  const handleCreateModal = () => {
    if (createModalOpen) {
      setCreateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setCreateModalOpen(true);
    }
  };
  // 编辑弹框
  const [updateModalOpen, setUpdateModalOpen] = useState<boolean>(false);

  const handleUpdateModal = () => {
    if (updateModalOpen) {
      setUpdateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setUpdateModalOpen(true);
    }
  };

  const getAlarmRulesList = async () => {
    return {
        code: 0,
        success: true,
        data: {
            "list": [
                {
                    "id": 1,
                    "createTime": "2023-10-17T02:35:41.14308Z",
                    "updateTime": "2023-10-17T02:35:41.14308Z",
                    "name": "单人徘徊告警",
                    "address": "https://xxxx%E5%BC%80%E5%85%B3",
                    "isEnabled": true,
                    "remark": ""
                },
                {
                    "id": 2,
                    "createTime": "2023-10-17T02:40:28.292883Z",
                    "updateTime": "2023-10-26T03:02:51.356036Z",
                    "name": "多人聚集告警",
                    "address": "https://xxxx%E5%BC%80%E5%85%B3",
                    "isEnabled": false,
                    "remark": ""
                },
                {
                    "id": 4,
                    "createTime": "2023-12-12T02:54:52.204957Z",
                    "updateTime": "2023-12-12T02:54:52.204957Z",
                    "name": "敏感时间段告警",
                    "address": "https://xxxx%E5%BC%80%E5%85%B3",
                    "isEnabled": false,
                    "remark": ""
                }
            ],
            "total": 3,
            "page": 1,
            "pageSize": 10
        },
        msg: "获取成功"
    }
  }

  const columns: ProColumns<API.DeviceCategory>[] = [
    {
      title: <FormattedMessage id="device.interface_manage.table.list.name" defaultMessage="$$$" />,
      dataIndex: 'device_name',
      hideInSearch: true,
    },

    {
      title: <FormattedMessage id="device.interface_manage.table.list.address" defaultMessage="$$$" />,
      dataIndex: 'device_api',
      hideInSearch: true,
    },
    {
      title: <FormattedMessage id="device.interface_manage.table.list.createTime" defaultMessage="$$$" />,
      dataIndex: 'create_time',
      sorter: true,
      hideInSearch: true,
      valueType: 'dateTime',
    },

    {
      title: <FormattedMessage id="pages.searchTable.titleOption" defaultMessage="Operating" />,
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      render: (_, record) => [
        <TableActionCard
          key="TableActionCardRef"
          renderActions={[
            {
                key: 'update',
                renderDom: (
                  <Button
                    key="update"
                    type="link"
                    size="small"
                    style={{
                        color:"#081FA8",
                        
                    }}
                    icon={<EditOutlined style={{
                        marginRight: 3
                    }} />}
                    onClick={() => {
                      setUpdateModalOpen(true);
                      setCurrentRow(record);
                    }}
                  >
                    <FormattedMessage id="common.edit" defaultMessage="Update" />
                  </Button>
                ),
              },
            {
              key: 'destroy',
              renderDom: (
                <IsDelete
                  deleteApi={() => {
                    handleDestroy(record).then(() => {});
                  }}
                ></IsDelete>
              ),
            },
          ]}
        ></TableActionCard>,
      ],
    },
  ];
  return (
    <PageContainer
        title={false}
        content={
        <div style={{
            display: 'flex',
            justifyContent: 'space-between'
        }}>
            <div style={{
            fontWeight: 600,
            fontSize: 20,
            color: '#333'
            }}>接口管理</div>
            <Button type="primary"
            onClick={() => {
                setCreateModalOpen(true);
            }}
            >
            <FormattedMessage id="device.interface_manage.table.list.add" defaultMessage="add" />
            </Button>
        </div>
        }
    >
      <ProTable<API.DeviceCategory>
        cardProps={{
          bodyStyle: {
            padding: 20
          }
        }}
        options={{ fullScreen: false, setting: false, density: false, reload: false }}
        actionRef={actionRef}
        rowKey="key"
        search={false}
        pagination={{
          ...proTablePaginationOptions,
          pageSize: currentPageSize,
          onChange: (page, pageSize) => setCurrentPageSize(pageSize),
        }}
        columnsState={{
          persistenceKey: 'device_category_list',
          persistenceType: 'localStorage',
        }}
        request={async (params = {}, sort) => {
          const { current, ...rest } = params;
          const reqParams = {
            page: current,
            desc: false,
            orderKey: '',
            ...rest,
          };
          if (sort && Object.keys(sort).length) {
            reqParams.orderKey = Object.keys(sort)[0];
            let sort_select = sort[reqParams.orderKey];
            reqParams.desc = sort_select === 'descend';
          }
        //   let resp = await postDeviceCategoryGetDeviceCategoryList({ ...reqParams });
          let resp = await getInterfaces({ ...reqParams });
          return {
            data: resp.data.results.map((v: API.DeviceCategory) => {
              return { ...v, key: v.id };
            }),
            success: resp.success,
            total: resp.data.count,
            current: resp.data.page,
            pageSize: resp.data.pageSize,
          };
        }}
        columns={columns}
      />
      <CreateForm
        createModalOpen={createModalOpen}
        values={currentRow || {}}
        handleModal={handleCreateModal}
        reload={actionRef.current?.reload}
      />
      <UpdateForm
        updateModalOpen={updateModalOpen}
        values={currentRow || {}}
        handleModal={handleUpdateModal}
        reload={actionRef.current?.reload}
      />
    </PageContainer>
  );
};

export default InterfaceManageList;
